- x
A data.frame, matrix, or similar object of covariates, where each
row represents a sample. If a mild_df object is passed, y, bags, instances are automatically extracted, and all other columns will be used
as predictors.
- y
A numeric, character, or factor vector of bag labels for each
instance. Must satisfy length(y) == nrow(x). Suggest that one of the
levels is 1, '1', or TRUE, which becomes the positive class; otherwise, a
positive class is chosen and a message will be supplied.
- bags
A vector specifying which instance belongs to each bag. Can be a
string, numeric, of factor.
- instances
A vector specifying which samples belong to each instance.
Can be a string, numeric, of factor.
- cost
The cost parameter in SVM. If method = 'heuristic', this will
be fed to kernlab::ksvm(), otherwise it is similarly in internal
functions.
- method
The algorithm to use in fitting (default 'heuristic'). When
method = 'heuristic', the algorithm iterates between selecting positive
witnesses and solving an underlying smm() problem. When method = 'mip', the novel MIP method will be used. When method = 'qp-heuristic',
the heuristic algorithm is computed using a slightly modified dual SMM.
See details
- weights
named vector, or TRUE, to control the weight of the cost
parameter for each possible y value. Weights multiply against the cost
vector. If TRUE, weights are calculated based on inverse counts of
instances with given label, where we only count one positive instance per
bag. Otherwise, names must match the levels of y.
- control
list of additional parameters passed to the method that
control computation with the following components:
kernel either a character the describes the kernel ('linear' or
'radial') or a kernel matrix at the instance level.
sigma argument needed for radial basis kernel.
nystrom_args a list of parameters to pass to kfm_nystrom(). This is
used when method = 'mip' and kernel = 'radial' to generate a Nystrom
approximation of the kernel features.
max_step argument used when method = 'heuristic'. Maximum steps of
iteration for the heuristic algorithm.
scale argument used for all methods. A logical for whether to rescale
the input before fitting.
verbose argument used when method = 'mip'. Whether to message output
to the console.
time_limit argument used when method = 'mip'. FALSE, or a time
limit (in seconds) passed to gurobi() parameters. If FALSE, no time
limit is given.
start argument used when method = 'mip'. If TRUE, the mip program
will be warm_started with the solution from method = 'qp-heuristic' to
potentially improve speed.
- ...
Arguments passed to or from other methods.
- formula
A formula with specification mild(y, bags, instances) ~ x
which uses the mild function to create the bag-instance structure. This
argument is an alternative to the x, y, bags, instances arguments, but
requires the data argument. See examples.
- data
If formula is provided, a data.frame or similar from which
formula elements will be extracted.